/* PaginationTimeline.c generated by valac 0.56.19, the Vala compiler
 * generated from PaginationTimeline.vala, do not modify */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <libsoup/soup.h>
#include <json-glib/json-glib.h>
#include <glib/gi18n-lib.h>
#include <adwaita.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE (tuba_views_admin_timeline_pagination_timeline_get_type ())
#define TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimeline))
#define TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimelineClass))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_PAGINATION_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_PAGINATION_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE))
#define TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimelineClass))

typedef struct _TubaViewsAdminTimelinePaginationTimeline TubaViewsAdminTimelinePaginationTimeline;
typedef struct _TubaViewsAdminTimelinePaginationTimelineClass TubaViewsAdminTimelinePaginationTimelineClass;
typedef struct _TubaViewsAdminTimelinePaginationTimelinePrivate TubaViewsAdminTimelinePaginationTimelinePrivate;
enum  {
	TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_0_PROPERTY,
	TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_URL_PROPERTY,
	TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_ACCEPTS_PROPERTY,
	TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_WORKING_PROPERTY,
	TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_PAGE_NEXT_PROPERTY,
	TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_PAGE_PREV_PROPERTY,
	TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_NUM_PROPERTIES
};
static GParamSpec* tuba_views_admin_timeline_pagination_timeline_properties[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;
typedef enum  {
	TUBA_REQUEST_V2_METHOD_GET,
	TUBA_REQUEST_V2_METHOD_POST,
	TUBA_REQUEST_V2_METHOD_PUT,
	TUBA_REQUEST_V2_METHOD_DELETE,
	TUBA_REQUEST_V2_METHOD_PATCH
} TubaRequestV2Method;

#define TUBA_REQUEST_V2_TYPE_METHOD (tuba_request_v2_method_get_type ())

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_TYPE_OOPSIE (tuba_oopsie_get_type ())
#define _soup_message_headers_unref0(var) ((var == NULL) ? NULL : (var = (soup_message_headers_unref (var), NULL)))
typedef void (*TubaNetworkNodeCallback) (JsonNode* node, gpointer user_data, GError** error);
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _TubaViewsAdminTimelinePaginationTimelineRequestData TubaViewsAdminTimelinePaginationTimelineRequestData;

#define TUBA_TYPE_BASIC_WIDGETIZABLE (tuba_basic_widgetizable_get_type ())
#define TUBA_BASIC_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_BASIC_WIDGETIZABLE, TubaBasicWidgetizable))
#define TUBA_IS_BASIC_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_BASIC_WIDGETIZABLE))
#define TUBA_BASIC_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_BASIC_WIDGETIZABLE, TubaBasicWidgetizableIface))

typedef struct _TubaBasicWidgetizable TubaBasicWidgetizable;
typedef struct _TubaBasicWidgetizableIface TubaBasicWidgetizableIface;
enum  {
	TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_ON_ERROR_SIGNAL,
	TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_NUM_SIGNALS
};
static guint tuba_views_admin_timeline_pagination_timeline_signals[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_NUM_SIGNALS] = {0};

struct _TubaViewsAdminTimelinePaginationTimeline {
	GtkBox parent_instance;
	TubaViewsAdminTimelinePaginationTimelinePrivate * priv;
	GtkListBox* content;
};

struct _TubaViewsAdminTimelinePaginationTimelineClass {
	GtkBoxClass parent_class;
	void (*request) (TubaViewsAdminTimelinePaginationTimeline* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*request_finish) (TubaViewsAdminTimelinePaginationTimeline* self, GAsyncResult* _res_);
	GtkWidget* (*on_create_model_widget) (TubaViewsAdminTimelinePaginationTimeline* self, GObject* obj);
	void (*on_content_item_activated) (TubaViewsAdminTimelinePaginationTimeline* self, GtkListBoxRow* row);
};

struct _TubaViewsAdminTimelinePaginationTimelinePrivate {
	gchar* _url;
	GType _accepts;
	gboolean _working;
	gchar* _page_next;
	gchar* _page_prev;
	GtkButton* prev_button;
	GtkButton* next_button;
	gboolean first_page;
};

typedef enum  {
	TUBA_OOPSIE_USER,
	TUBA_OOPSIE_PARSING,
	TUBA_OOPSIE_INSTANCE,
	TUBA_OOPSIE_INTERNAL,
	TUBA_OOPSIE_HTTP_401 = 401,
	TUBA_OOPSIE_HTTP_403 = 403,
	TUBA_OOPSIE_HTTP_404 = 404,
	TUBA_OOPSIE_HTTP_410 = 410,
	TUBA_OOPSIE_HTTP_422 = 422,
	TUBA_OOPSIE_HTTP_429 = 429,
	TUBA_OOPSIE_HTTP_500 = 500,
	TUBA_OOPSIE_HTTP_503 = 503
} TubaOopsie;
#define TUBA_OOPSIE tuba_oopsie_quark ()

struct _TubaViewsAdminTimelinePaginationTimelineRequestData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaViewsAdminTimelinePaginationTimeline* self;
	GType _tmp0_;
	GtkButton* _tmp1_;
	GtkButton* _tmp2_;
	TubaRequestV2* req;
	const gchar* _tmp3_;
	TubaAccountStore* _tmp4_;
	TubaInstanceAccount* _tmp5_;
	TubaInstanceAccount* _tmp6_;
	TubaInstanceAccount* _tmp7_;
	TubaRequestV2* _tmp8_;
	GInputStream* in_stream;
	SoupMessageHeaders* response_headers;
	GInputStream* _tmp9_;
	TubaRequestV2* _tmp10_;
	SoupMessageHeaders* _tmp11_;
	GInputStream* _tmp12_;
	GInputStream* _tmp13_;
	GtkListBox* _tmp14_;
	JsonParser* parser;
	GInputStream* _tmp15_;
	JsonParser* _tmp16_;
	JsonParser* _tmp17_;
	SoupMessageHeaders* _tmp18_;
	SoupMessageHeaders* _tmp19_;
	const gchar* _tmp20_;
	GError* e;
	GError* _tmp21_;
	GError* _tmp22_;
	const gchar* _tmp23_;
	GError* _inner_error0_;
};

struct _TubaBasicWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaBasicWidgetizable* self);
};

static gint TubaViewsAdminTimelinePaginationTimeline_private_offset;
static gpointer tuba_views_admin_timeline_pagination_timeline_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;

VALA_EXTERN GType tuba_views_admin_timeline_pagination_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminTimelinePaginationTimeline, g_object_unref)
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_request (TubaViewsAdminTimelinePaginationTimeline* self,
                                                            GAsyncReadyCallback _callback_,
                                                            gpointer _user_data_);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_request_finish (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                   GAsyncResult* _res_);
VALA_EXTERN GtkWidget* tuba_views_admin_timeline_pagination_timeline_on_create_model_widget (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                                 GObject* obj);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_on_content_item_activated (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                              GtkListBoxRow* row);
static void tuba_views_admin_timeline_pagination_timeline_on_next (TubaViewsAdminTimelinePaginationTimeline* self);
VALA_EXTERN const gchar* tuba_views_admin_timeline_pagination_timeline_get_page_next (TubaViewsAdminTimelinePaginationTimeline* self);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_set_url (TubaViewsAdminTimelinePaginationTimeline* self,
                                                            const gchar* value);
static void tuba_views_admin_timeline_pagination_timeline_on_prev (TubaViewsAdminTimelinePaginationTimeline* self);
VALA_EXTERN const gchar* tuba_views_admin_timeline_pagination_timeline_get_page_prev (TubaViewsAdminTimelinePaginationTimeline* self);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_get_pages (TubaViewsAdminTimelinePaginationTimeline* self,
                                                              const gchar* header);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_set_page_prev (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                  const gchar* value);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_set_page_next (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                  const gchar* value);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_reset (TubaViewsAdminTimelinePaginationTimeline* self,
                                                          const gchar* new_url);
static void tuba_views_admin_timeline_pagination_timeline_real_request_data_free (gpointer _data);
static void tuba_views_admin_timeline_pagination_timeline_real_request (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                 GAsyncReadyCallback _callback_,
                                                                 gpointer _user_data_);
static gboolean tuba_views_admin_timeline_pagination_timeline_real_request_co (TubaViewsAdminTimelinePaginationTimelineRequestData* _data_);
VALA_EXTERN GType tuba_views_admin_timeline_pagination_timeline_get_accepts (TubaViewsAdminTimelinePaginationTimeline* self);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_set_working (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                gboolean value);
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN const gchar* tuba_views_admin_timeline_pagination_timeline_get_url (TubaViewsAdminTimelinePaginationTimeline* self);
VALA_EXTERN GType tuba_request_v2_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN TubaRequestV2* tuba_request_v2_new (const gchar* url,
                                    TubaRequestV2Method method);
VALA_EXTERN TubaRequestV2* tuba_request_v2_construct (GType object_type,
                                          const gchar* url,
                                          TubaRequestV2Method method);
VALA_EXTERN void tuba_request_v2_set_account (TubaRequestV2* self,
                                  TubaInstanceAccount* value);
VALA_EXTERN void tuba_request_v2_set_ctx (TubaRequestV2* self,
                              GtkWidget* value);
VALA_EXTERN void tuba_request_v2_exec (TubaRequestV2* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN GQuark tuba_oopsie_quark (void);
VALA_EXTERN GType tuba_oopsie_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GInputStream* tuba_request_v2_exec_finish (TubaRequestV2* self,
                                           GAsyncResult* _res_,
                                           SoupMessageHeaders** response_headers,
                                           GError** error);
static void tuba_views_admin_timeline_pagination_timeline_request_ready (GObject* source_object,
                                                                  GAsyncResult* _res_,
                                                                  gpointer _user_data_);
VALA_EXTERN void tuba_network_get_parser_from_inputstream_async (GInputStream* in_stream,
                                                     GCancellable* cancellable,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN JsonParser* tuba_network_get_parser_from_inputstream_finish (GAsyncResult* _res_,
                                                             GError** error);
VALA_EXTERN void tuba_network_parse_array (JsonParser* parser,
                               TubaNetworkNodeCallback cb,
                               gpointer cb_target,
                               GDestroyNotify cb_target_destroy_notify,
                               GError** error);
static void ___lambda109_ (TubaViewsAdminTimelinePaginationTimeline* self,
                    JsonNode* node,
                    GError** error);
VALA_EXTERN TubaEntity* tuba_helper_entity_from_json (JsonNode* node,
                                          GType type,
                                          gboolean force);
static JsonNode* _vala_JsonNode_copy (JsonNode* self);
static void ____lambda109__tuba_network_node_callback (JsonNode* node,
                                                gpointer self,
                                                GError** error);
static GtkWidget* tuba_views_admin_timeline_pagination_timeline_real_on_create_model_widget (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                                      GObject* obj);
VALA_EXTERN GType tuba_basic_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaBasicWidgetizable, g_object_unref)
VALA_EXTERN GtkWidget* tuba_basic_widgetizable_to_widget (TubaBasicWidgetizable* self);
static void tuba_views_admin_timeline_pagination_timeline_real_on_content_item_activated (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                                   GtkListBoxRow* row);
VALA_EXTERN TubaViewsAdminTimelinePaginationTimeline* tuba_views_admin_timeline_pagination_timeline_new (void);
VALA_EXTERN TubaViewsAdminTimelinePaginationTimeline* tuba_views_admin_timeline_pagination_timeline_construct (GType object_type);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_set_accepts (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                GType value);
VALA_EXTERN gboolean tuba_views_admin_timeline_pagination_timeline_get_working (TubaViewsAdminTimelinePaginationTimeline* self);
static void g_cclosure_user_marshal_VOID__INT_STRING (GClosure * closure,
                                               GValue * return_value,
                                               guint n_param_values,
                                               const GValue * param_values,
                                               gpointer invocation_hint,
                                               gpointer marshal_data);
static GObject * tuba_views_admin_timeline_pagination_timeline_constructor (GType type,
                                                                     guint n_construct_properties,
                                                                     GObjectConstructParam * construct_properties);
static void _tuba_views_admin_timeline_pagination_timeline_on_content_item_activated_gtk_list_box_row_activated (GtkListBox* _sender,
                                                                                                          GtkListBoxRow* row,
                                                                                                          gpointer self);
static void _tuba_views_admin_timeline_pagination_timeline_on_prev_gtk_button_clicked (GtkButton* _sender,
                                                                                gpointer self);
static void _tuba_views_admin_timeline_pagination_timeline_on_next_gtk_button_clicked (GtkButton* _sender,
                                                                                gpointer self);
static void tuba_views_admin_timeline_pagination_timeline_finalize (GObject * obj);
static GType tuba_views_admin_timeline_pagination_timeline_get_type_once (void);
static void _vala_tuba_views_admin_timeline_pagination_timeline_get_property (GObject * object,
                                                                       guint property_id,
                                                                       GValue * value,
                                                                       GParamSpec * pspec);
static void _vala_tuba_views_admin_timeline_pagination_timeline_set_property (GObject * object,
                                                                       guint property_id,
                                                                       const GValue * value,
                                                                       GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);
static gssize _vala_array_length (gpointer array);

static inline gpointer
tuba_views_admin_timeline_pagination_timeline_get_instance_private (TubaViewsAdminTimelinePaginationTimeline* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsAdminTimelinePaginationTimeline_private_offset);
}

static void
tuba_views_admin_timeline_pagination_timeline_on_next (TubaViewsAdminTimelinePaginationTimeline* self)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	g_return_if_fail (self != NULL);
	self->priv->first_page = FALSE;
	_tmp0_ = tuba_views_admin_timeline_pagination_timeline_get_page_next (self);
	_tmp1_ = _tmp0_;
	tuba_views_admin_timeline_pagination_timeline_set_url (self, _tmp1_);
	tuba_views_admin_timeline_pagination_timeline_request (self, NULL, NULL);
}

static void
tuba_views_admin_timeline_pagination_timeline_on_prev (TubaViewsAdminTimelinePaginationTimeline* self)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	g_return_if_fail (self != NULL);
	self->priv->first_page = FALSE;
	_tmp0_ = tuba_views_admin_timeline_pagination_timeline_get_page_prev (self);
	_tmp1_ = _tmp0_;
	tuba_views_admin_timeline_pagination_timeline_set_url (self, _tmp1_);
	tuba_views_admin_timeline_pagination_timeline_request (self, NULL, NULL);
}

static gchar*
string_replace (const gchar* self,
                const gchar* old,
                const gchar* replacement)
{
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError* _inner_error0_ = NULL;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (old != NULL, NULL);
	g_return_val_if_fail (replacement != NULL, NULL);
	if ((*((gchar*) self)) == '\0') {
		_tmp1_ = TRUE;
	} else {
		_tmp1_ = (*((gchar*) old)) == '\0';
	}
	if (_tmp1_) {
		_tmp0_ = TRUE;
	} else {
		_tmp0_ = g_strcmp0 (old, replacement) == 0;
	}
	if (_tmp0_) {
		gchar* _tmp2_;
		_tmp2_ = g_strdup (self);
		result = _tmp2_;
		return result;
	}
	{
		GRegex* regex = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
		GRegex* _tmp5_;
		GRegex* _tmp6_;
		gchar* _tmp7_ = NULL;
		GRegex* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		_tmp3_ = g_regex_escape_string (old, -1);
		_tmp4_ = _tmp3_;
		_tmp5_ = g_regex_new (_tmp4_, 0, 0, &_inner_error0_);
		_tmp6_ = _tmp5_;
		_g_free0 (_tmp4_);
		regex = _tmp6_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch0_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp8_ = regex;
		_tmp9_ = g_regex_replace_literal (_tmp8_, self, (gssize) -1, 0, replacement, 0, &_inner_error0_);
		_tmp7_ = _tmp9_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			_g_regex_unref0 (regex);
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch0_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp10_ = _tmp7_;
		_tmp7_ = NULL;
		result = _tmp10_;
		_g_free0 (_tmp7_);
		_g_regex_unref0 (regex);
		return result;
	}
	goto __finally0;
	__catch0_g_regex_error:
	{
		g_clear_error (&_inner_error0_);
		g_assert_not_reached ();
	}
	__finally0:
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
	g_clear_error (&_inner_error0_);
	return NULL;
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gchar* _tmp0_;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (needle != NULL, FALSE);
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
	result = _tmp0_ != NULL;
	return result;
}

void
tuba_views_admin_timeline_pagination_timeline_get_pages (TubaViewsAdminTimelinePaginationTimeline* self,
                                                         const gchar* header)
{
	gchar** pages = NULL;
	gchar** _tmp0_;
	gchar** _tmp1_;
	gint pages_length1;
	gint _pages_size_;
	gchar** _tmp2_;
	gint _tmp2__length1;
	g_return_if_fail (self != NULL);
	tuba_views_admin_timeline_pagination_timeline_set_page_prev (self, NULL);
	tuba_views_admin_timeline_pagination_timeline_set_page_next (self, NULL);
	if (header == NULL) {
		return;
	}
	_tmp1_ = _tmp0_ = g_strsplit (header, ",", 0);
	pages = _tmp1_;
	pages_length1 = _vala_array_length (_tmp0_);
	_pages_size_ = pages_length1;
	_tmp2_ = pages;
	_tmp2__length1 = pages_length1;
	{
		gchar** page_collection = NULL;
		gint page_collection_length1 = 0;
		gint _page_collection_size_ = 0;
		gint page_it = 0;
		page_collection = _tmp2_;
		page_collection_length1 = _tmp2__length1;
		for (page_it = 0; page_it < page_collection_length1; page_it = page_it + 1) {
			gchar* _tmp3_;
			gchar* page = NULL;
			_tmp3_ = g_strdup (page_collection[page_it]);
			page = _tmp3_;
			{
				gchar* sanitized = NULL;
				const gchar* _tmp4_;
				gchar* _tmp5_;
				gchar* _tmp6_;
				gchar* _tmp7_;
				gchar* _tmp8_;
				gchar** _tmp9_;
				gchar** _tmp10_;
				gchar** _tmp11_;
				gint _tmp11__length1;
				const gchar* _tmp12_;
				gchar* _tmp13_;
				gchar* _tmp14_;
				const gchar* _tmp15_;
				_tmp4_ = page;
				_tmp5_ = string_replace (_tmp4_, "<", "");
				_tmp6_ = _tmp5_;
				_tmp7_ = string_replace (_tmp6_, ">", "");
				_tmp8_ = _tmp7_;
				_tmp10_ = _tmp9_ = g_strsplit (_tmp8_, ";", 0);
				_tmp11_ = _tmp10_;
				_tmp11__length1 = _vala_array_length (_tmp9_);
				_tmp12_ = _tmp11_[0];
				_tmp13_ = g_strdup (_tmp12_);
				_tmp14_ = _tmp13_;
				_tmp11_ = (_vala_array_free (_tmp11_, _tmp11__length1, (GDestroyNotify) g_free), NULL);
				_g_free0 (_tmp8_);
				_g_free0 (_tmp6_);
				sanitized = _tmp14_;
				_tmp15_ = page;
				if (string_contains (_tmp15_, "rel=\"prev\"")) {
					if (!self->priv->first_page) {
						const gchar* _tmp16_;
						_tmp16_ = sanitized;
						tuba_views_admin_timeline_pagination_timeline_set_page_prev (self, _tmp16_);
					}
				} else {
					const gchar* _tmp17_;
					_tmp17_ = sanitized;
					tuba_views_admin_timeline_pagination_timeline_set_page_next (self, _tmp17_);
				}
				_g_free0 (sanitized);
				_g_free0 (page);
			}
		}
	}
	pages = (_vala_array_free (pages, pages_length1, (GDestroyNotify) g_free), NULL);
}

void
tuba_views_admin_timeline_pagination_timeline_reset (TubaViewsAdminTimelinePaginationTimeline* self,
                                                     const gchar* new_url)
{
	g_return_if_fail (self != NULL);
	g_return_if_fail (new_url != NULL);
	tuba_views_admin_timeline_pagination_timeline_set_url (self, new_url);
	self->priv->first_page = TRUE;
	tuba_views_admin_timeline_pagination_timeline_request (self, NULL, NULL);
}

static void
tuba_views_admin_timeline_pagination_timeline_real_request_data_free (gpointer _data)
{
	TubaViewsAdminTimelinePaginationTimelineRequestData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaViewsAdminTimelinePaginationTimelineRequestData, _data_);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
tuba_views_admin_timeline_pagination_timeline_real_request (TubaViewsAdminTimelinePaginationTimeline* self,
                                                            GAsyncReadyCallback _callback_,
                                                            gpointer _user_data_)
{
	TubaViewsAdminTimelinePaginationTimelineRequestData* _data_;
	TubaViewsAdminTimelinePaginationTimeline* _tmp0_;
	_data_ = g_slice_new0 (TubaViewsAdminTimelinePaginationTimelineRequestData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_views_admin_timeline_pagination_timeline_real_request_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	tuba_views_admin_timeline_pagination_timeline_real_request_co (_data_);
}

static void
tuba_views_admin_timeline_pagination_timeline_real_request_finish (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                   GAsyncResult* _res_)
{
	TubaViewsAdminTimelinePaginationTimelineRequestData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
tuba_views_admin_timeline_pagination_timeline_request_ready (GObject* source_object,
                                                             GAsyncResult* _res_,
                                                             gpointer _user_data_)
{
	TubaViewsAdminTimelinePaginationTimelineRequestData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_views_admin_timeline_pagination_timeline_real_request_co (_data_);
}

static JsonNode*
_vala_JsonNode_copy (JsonNode* self)
{
	return g_boxed_copy (json_node_get_type (), self);
}

static gpointer
__vala_JsonNode_copy0 (gpointer self)
{
	return self ? _vala_JsonNode_copy (self) : NULL;
}

static void
___lambda109_ (TubaViewsAdminTimelinePaginationTimeline* self,
               JsonNode* node,
               GError** error)
{
	GtkListBox* _tmp0_;
	JsonNode* _tmp1_;
	GType _tmp2_;
	TubaEntity* _tmp3_;
	TubaEntity* _tmp4_;
	GtkWidget* _tmp5_;
	GtkWidget* _tmp6_;
	g_return_if_fail (node != NULL);
	_tmp0_ = self->content;
	_tmp1_ = __vala_JsonNode_copy0 (node);
	_tmp2_ = self->priv->_accepts;
	_tmp3_ = tuba_helper_entity_from_json (_tmp1_, _tmp2_, FALSE);
	_tmp4_ = _tmp3_;
	_tmp5_ = tuba_views_admin_timeline_pagination_timeline_on_create_model_widget (self, (GObject*) _tmp4_);
	_tmp6_ = _tmp5_;
	gtk_list_box_append (_tmp0_, _tmp6_);
	_g_object_unref0 (_tmp6_);
	_g_object_unref0 (_tmp4_);
}

static void
____lambda109__tuba_network_node_callback (JsonNode* node,
                                           gpointer self,
                                           GError** error)
{
	___lambda109_ ((TubaViewsAdminTimelinePaginationTimeline*) self, node, error);
}

static gboolean
tuba_views_admin_timeline_pagination_timeline_real_request_co (TubaViewsAdminTimelinePaginationTimelineRequestData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = _data_->self->priv->_accepts;
	if (_data_->_tmp0_ == G_TYPE_NONE) {
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
		if (_data_->_state_ != 0) {
			while (!g_task_get_completed (_data_->_async_result)) {
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
			}
		}
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp1_ = _data_->self->priv->next_button;
	_data_->_tmp2_ = _data_->self->priv->prev_button;
	gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp2_, FALSE);
	gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp1_, FALSE);
	tuba_views_admin_timeline_pagination_timeline_set_working (_data_->self, TRUE);
	_data_->_tmp3_ = _data_->self->priv->_url;
	_data_->_tmp4_ = tuba_accounts;
	_data_->_tmp5_ = tuba_account_store_get_active (_data_->_tmp4_);
	_data_->_tmp6_ = _data_->_tmp5_;
	_data_->_tmp7_ = _g_object_ref0 (_data_->_tmp6_);
	_data_->_tmp8_ = NULL;
	_data_->_tmp8_ = tuba_request_v2_new (_data_->_tmp3_, TUBA_REQUEST_V2_METHOD_GET);
	tuba_request_v2_set_account (_data_->_tmp8_, _data_->_tmp7_);
	_g_object_unref0 (_data_->_tmp7_);
	tuba_request_v2_set_ctx (_data_->_tmp8_, (GtkWidget*) _data_->self);
	_data_->req = _data_->_tmp8_;
	{
		_data_->_tmp10_ = _data_->req;
		_data_->_tmp11_ = NULL;
		_data_->_state_ = 1;
		tuba_request_v2_exec (_data_->_tmp10_, tuba_views_admin_timeline_pagination_timeline_request_ready, _data_);
		return FALSE;
		_state_1:
		_data_->_tmp12_ = tuba_request_v2_exec_finish (_data_->_tmp10_, _data_->_res_, &_data_->_tmp11_, &_data_->_inner_error0_);
		_soup_message_headers_unref0 (_data_->response_headers);
		_data_->response_headers = _data_->_tmp11_;
		_data_->_tmp9_ = _data_->_tmp12_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			if (g_error_matches (_data_->_inner_error0_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
				goto __catch0_g_io_error_cancelled;
			}
			goto __catch0_g_error;
		}
		_data_->_tmp13_ = _data_->_tmp9_;
		_data_->_tmp9_ = NULL;
		_g_object_unref0 (_data_->in_stream);
		_data_->in_stream = _data_->_tmp13_;
		_data_->_tmp14_ = _data_->self->content;
		gtk_list_box_remove_all (_data_->_tmp14_);
		_data_->_tmp15_ = _data_->in_stream;
		_data_->_state_ = 2;
		tuba_network_get_parser_from_inputstream_async (_data_->_tmp15_, NULL, tuba_views_admin_timeline_pagination_timeline_request_ready, _data_);
		return FALSE;
		_state_2:
		_data_->_tmp16_ = tuba_network_get_parser_from_inputstream_finish (_data_->_res_, &_data_->_inner_error0_);
		_data_->parser = _data_->_tmp16_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->_tmp9_);
			if (g_error_matches (_data_->_inner_error0_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
				goto __catch0_g_io_error_cancelled;
			}
			goto __catch0_g_error;
		}
		_data_->_tmp17_ = _data_->parser;
		tuba_network_parse_array (_data_->_tmp17_, ____lambda109__tuba_network_node_callback, g_object_ref (_data_->self), g_object_unref, &_data_->_inner_error0_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->parser);
			_g_object_unref0 (_data_->_tmp9_);
			if (g_error_matches (_data_->_inner_error0_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
				goto __catch0_g_io_error_cancelled;
			}
			goto __catch0_g_error;
		}
		tuba_views_admin_timeline_pagination_timeline_set_working (_data_->self, FALSE);
		_data_->_tmp18_ = _data_->response_headers;
		if (_data_->_tmp18_ != NULL) {
			_data_->_tmp19_ = _data_->response_headers;
			_data_->_tmp20_ = soup_message_headers_get_one (_data_->_tmp19_, "Link");
			tuba_views_admin_timeline_pagination_timeline_get_pages (_data_->self, _data_->_tmp20_);
		}
		_g_object_unref0 (_data_->parser);
		_g_object_unref0 (_data_->_tmp9_);
	}
	goto __finally0;
	__catch0_g_io_error_cancelled:
	{
		g_clear_error (&_data_->_inner_error0_);
		g_debug ("PaginationTimeline.vala:148: Message is cancelled.");
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp21_ = _data_->e;
		_data_->_tmp22_ = _data_->e;
		_data_->_tmp23_ = _data_->_tmp22_->message;
		g_signal_emit (_data_->self, tuba_views_admin_timeline_pagination_timeline_signals[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_ON_ERROR_SIGNAL], 0, _data_->_tmp21_->code, _data_->_tmp23_);
		_g_error_free0 (_data_->e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_soup_message_headers_unref0 (_data_->response_headers);
		_g_object_unref0 (_data_->in_stream);
		_g_object_unref0 (_data_->req);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_soup_message_headers_unref0 (_data_->response_headers);
	_g_object_unref0 (_data_->in_stream);
	_g_object_unref0 (_data_->req);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

void
tuba_views_admin_timeline_pagination_timeline_request (TubaViewsAdminTimelinePaginationTimeline* self,
                                                       GAsyncReadyCallback _callback_,
                                                       gpointer _user_data_)
{
	TubaViewsAdminTimelinePaginationTimelineClass* _klass_;
	_klass_ = TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_GET_CLASS (self);
	if (_klass_->request) {
		_klass_->request (self, _callback_, _user_data_);
	}
}

void
tuba_views_admin_timeline_pagination_timeline_request_finish (TubaViewsAdminTimelinePaginationTimeline* self,
                                                              GAsyncResult* _res_)
{
	TubaViewsAdminTimelinePaginationTimelineClass* _klass_;
	_klass_ = TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_GET_CLASS (self);
	if (_klass_->request_finish) {
		_klass_->request_finish (self, _res_);
	}
}

static GtkWidget*
tuba_views_admin_timeline_pagination_timeline_real_on_create_model_widget (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                           GObject* obj)
{
	TubaBasicWidgetizable* obj_widgetable = NULL;
	TubaBasicWidgetizable* _tmp0_;
	GtkWidget* widget = NULL;
	GtkWidget* _tmp1_;
	GtkWidget* result;
	g_return_val_if_fail (obj != NULL, NULL);
	_tmp0_ = _g_object_ref0 (TUBA_IS_BASIC_WIDGETIZABLE (obj) ? ((TubaBasicWidgetizable*) obj) : NULL);
	obj_widgetable = _tmp0_;
	if (obj_widgetable == NULL) {
		exit (0);
	}
	_tmp1_ = tuba_basic_widgetizable_to_widget (obj_widgetable);
	widget = _tmp1_;
	gtk_widget_add_css_class (widget, "card");
	gtk_widget_add_css_class (widget, "card-spacing");
	gtk_widget_set_focusable (widget, TRUE);
	result = widget;
	_g_object_unref0 (obj_widgetable);
	return result;
}

GtkWidget*
tuba_views_admin_timeline_pagination_timeline_on_create_model_widget (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                      GObject* obj)
{
	TubaViewsAdminTimelinePaginationTimelineClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_GET_CLASS (self);
	if (_klass_->on_create_model_widget) {
		return _klass_->on_create_model_widget (self, obj);
	}
	return NULL;
}

static void
tuba_views_admin_timeline_pagination_timeline_real_on_content_item_activated (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                              GtkListBoxRow* row)
{
	g_return_if_fail (row != NULL);
}

void
tuba_views_admin_timeline_pagination_timeline_on_content_item_activated (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                         GtkListBoxRow* row)
{
	TubaViewsAdminTimelinePaginationTimelineClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_GET_CLASS (self);
	if (_klass_->on_content_item_activated) {
		_klass_->on_content_item_activated (self, row);
	}
}

TubaViewsAdminTimelinePaginationTimeline*
tuba_views_admin_timeline_pagination_timeline_construct (GType object_type)
{
	TubaViewsAdminTimelinePaginationTimeline * self = NULL;
	self = (TubaViewsAdminTimelinePaginationTimeline*) g_object_new (object_type, NULL);
	return self;
}

TubaViewsAdminTimelinePaginationTimeline*
tuba_views_admin_timeline_pagination_timeline_new (void)
{
	return tuba_views_admin_timeline_pagination_timeline_construct (TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE);
}

const gchar*
tuba_views_admin_timeline_pagination_timeline_get_url (TubaViewsAdminTimelinePaginationTimeline* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_url;
	result = _tmp0_;
	return result;
}

void
tuba_views_admin_timeline_pagination_timeline_set_url (TubaViewsAdminTimelinePaginationTimeline* self,
                                                       const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_admin_timeline_pagination_timeline_get_url (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_url);
		self->priv->_url = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_admin_timeline_pagination_timeline_properties[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_URL_PROPERTY]);
	}
}

GType
tuba_views_admin_timeline_pagination_timeline_get_accepts (TubaViewsAdminTimelinePaginationTimeline* self)
{
	GType result;
	g_return_val_if_fail (self != NULL, G_TYPE_INVALID);
	result = self->priv->_accepts;
	return result;
}

void
tuba_views_admin_timeline_pagination_timeline_set_accepts (TubaViewsAdminTimelinePaginationTimeline* self,
                                                           GType value)
{
	GType old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_admin_timeline_pagination_timeline_get_accepts (self);
	if (old_value != value) {
		self->priv->_accepts = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_admin_timeline_pagination_timeline_properties[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_ACCEPTS_PROPERTY]);
	}
}

gboolean
tuba_views_admin_timeline_pagination_timeline_get_working (TubaViewsAdminTimelinePaginationTimeline* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_working;
	return result;
}

void
tuba_views_admin_timeline_pagination_timeline_set_working (TubaViewsAdminTimelinePaginationTimeline* self,
                                                           gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_admin_timeline_pagination_timeline_get_working (self);
	if (old_value != value) {
		self->priv->_working = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_admin_timeline_pagination_timeline_properties[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_WORKING_PROPERTY]);
	}
}

const gchar*
tuba_views_admin_timeline_pagination_timeline_get_page_next (TubaViewsAdminTimelinePaginationTimeline* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_page_next;
	result = _tmp0_;
	return result;
}

void
tuba_views_admin_timeline_pagination_timeline_set_page_next (TubaViewsAdminTimelinePaginationTimeline* self,
                                                             const gchar* value)
{
	gchar* _tmp0_;
	GtkButton* _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_page_next);
	self->priv->_page_next = _tmp0_;
	_tmp1_ = self->priv->next_button;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp1_, value != NULL);
	g_object_notify_by_pspec ((GObject *) self, tuba_views_admin_timeline_pagination_timeline_properties[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_PAGE_NEXT_PROPERTY]);
}

const gchar*
tuba_views_admin_timeline_pagination_timeline_get_page_prev (TubaViewsAdminTimelinePaginationTimeline* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_page_prev;
	result = _tmp0_;
	return result;
}

void
tuba_views_admin_timeline_pagination_timeline_set_page_prev (TubaViewsAdminTimelinePaginationTimeline* self,
                                                             const gchar* value)
{
	gchar* _tmp0_;
	GtkButton* _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_page_prev);
	self->priv->_page_prev = _tmp0_;
	_tmp1_ = self->priv->prev_button;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp1_, value != NULL);
	g_object_notify_by_pspec ((GObject *) self, tuba_views_admin_timeline_pagination_timeline_properties[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_PAGE_PREV_PROPERTY]);
}

static void
g_cclosure_user_marshal_VOID__INT_STRING (GClosure * closure,
                                          GValue * return_value,
                                          guint n_param_values,
                                          const GValue * param_values,
                                          gpointer invocation_hint,
                                          gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__INT_STRING) (gpointer data1, gint arg_1, const char* arg_2, gpointer data2);
	register GMarshalFunc_VOID__INT_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 3);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__INT_STRING) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_int (param_values + 1), g_value_get_string (param_values + 2), data2);
}

static void
_tuba_views_admin_timeline_pagination_timeline_on_content_item_activated_gtk_list_box_row_activated (GtkListBox* _sender,
                                                                                                     GtkListBoxRow* row,
                                                                                                     gpointer self)
{
	tuba_views_admin_timeline_pagination_timeline_on_content_item_activated ((TubaViewsAdminTimelinePaginationTimeline*) self, row);
}

static void
_tuba_views_admin_timeline_pagination_timeline_on_prev_gtk_button_clicked (GtkButton* _sender,
                                                                           gpointer self)
{
	tuba_views_admin_timeline_pagination_timeline_on_prev ((TubaViewsAdminTimelinePaginationTimeline*) self);
}

static void
_tuba_views_admin_timeline_pagination_timeline_on_next_gtk_button_clicked (GtkButton* _sender,
                                                                           gpointer self)
{
	tuba_views_admin_timeline_pagination_timeline_on_next ((TubaViewsAdminTimelinePaginationTimeline*) self);
}

static GObject *
tuba_views_admin_timeline_pagination_timeline_constructor (GType type,
                                                           guint n_construct_properties,
                                                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaViewsAdminTimelinePaginationTimeline * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar** _tmp2_;
	GtkListBox* _tmp3_ = NULL;
	GtkListBox* _tmp4_;
	GtkBox* pagination_buttons = NULL;
	GtkBox* _tmp5_ = NULL;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar** _tmp8_;
	gchar* _tmp9_;
	GtkButton* _tmp10_ = NULL;
	GtkButton* _tmp11_;
	GtkBox* _tmp12_;
	GtkButton* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	gchar** _tmp16_;
	gchar* _tmp17_;
	GtkButton* _tmp18_ = NULL;
	GtkButton* _tmp19_;
	GtkBox* _tmp20_;
	GtkButton* _tmp21_;
	gchar* _tmp22_;
	gchar** _tmp23_;
	GtkListBox* _tmp24_;
	GtkWidget* _tmp25_;
	AdwClamp* _tmp26_ = NULL;
	AdwClamp* _tmp27_;
	GtkBox* _tmp28_;
	parent_class = G_OBJECT_CLASS (tuba_views_admin_timeline_pagination_timeline_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimeline);
	gtk_orientable_set_orientation ((GtkOrientable*) self, GTK_ORIENTATION_VERTICAL);
	gtk_box_set_spacing ((GtkBox*) self, 12);
	_tmp0_ = g_strdup ("fake-content");
	_tmp1_ = g_strdup ("background");
	_tmp2_ = g_new0 (gchar*, 2 + 1);
	_tmp2_[0] = _tmp0_;
	_tmp2_[1] = _tmp1_;
	_tmp3_ = (GtkListBox*) gtk_list_box_new ();
	gtk_list_box_set_selection_mode (_tmp3_, GTK_SELECTION_NONE);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp3_, _tmp2_);
	_tmp2_ = (_vala_array_free (_tmp2_, 2, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp3_);
	_g_object_unref0 (self->content);
	self->content = _tmp3_;
	_tmp4_ = self->content;
	g_signal_connect_object (_tmp4_, "row-activated", (GCallback) _tuba_views_admin_timeline_pagination_timeline_on_content_item_activated_gtk_list_box_row_activated, self, 0);
	_tmp5_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
	gtk_box_set_homogeneous (_tmp5_, TRUE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp5_, TRUE);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp5_, 12);
	g_object_ref_sink (_tmp5_);
	pagination_buttons = _tmp5_;
	_tmp6_ = g_strdup ("circular");
	_tmp7_ = g_strdup ("flat");
	_tmp8_ = g_new0 (gchar*, 2 + 1);
	_tmp8_[0] = _tmp6_;
	_tmp8_[1] = _tmp7_;
	_tmp9_ = g_strdup (_ ("Previous Page"));
	_tmp10_ = (GtkButton*) gtk_button_new_from_icon_name ("tuba-left-large-symbolic");
	gtk_widget_set_css_classes ((GtkWidget*) _tmp10_, _tmp8_);
	_tmp8_ = (_vala_array_free (_tmp8_, 2, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_valign ((GtkWidget*) _tmp10_, GTK_ALIGN_CENTER);
	gtk_widget_set_halign ((GtkWidget*) _tmp10_, GTK_ALIGN_CENTER);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp10_, _tmp9_);
	_g_free0 (_tmp9_);
	g_object_ref_sink (_tmp10_);
	_g_object_unref0 (self->priv->prev_button);
	self->priv->prev_button = _tmp10_;
	_tmp11_ = self->priv->prev_button;
	g_signal_connect_object (_tmp11_, "clicked", (GCallback) _tuba_views_admin_timeline_pagination_timeline_on_prev_gtk_button_clicked, self, 0);
	_tmp12_ = pagination_buttons;
	_tmp13_ = self->priv->prev_button;
	gtk_box_append (_tmp12_, (GtkWidget*) _tmp13_);
	_tmp14_ = g_strdup ("circular");
	_tmp15_ = g_strdup ("flat");
	_tmp16_ = g_new0 (gchar*, 2 + 1);
	_tmp16_[0] = _tmp14_;
	_tmp16_[1] = _tmp15_;
	_tmp17_ = g_strdup (_ ("Next Page"));
	_tmp18_ = (GtkButton*) gtk_button_new_from_icon_name ("tuba-right-large-symbolic");
	gtk_widget_set_css_classes ((GtkWidget*) _tmp18_, _tmp16_);
	_tmp16_ = (_vala_array_free (_tmp16_, 2, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_valign ((GtkWidget*) _tmp18_, GTK_ALIGN_CENTER);
	gtk_widget_set_halign ((GtkWidget*) _tmp18_, GTK_ALIGN_CENTER);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp18_, _tmp17_);
	_g_free0 (_tmp17_);
	g_object_ref_sink (_tmp18_);
	_g_object_unref0 (self->priv->next_button);
	self->priv->next_button = _tmp18_;
	_tmp19_ = self->priv->next_button;
	g_signal_connect_object (_tmp19_, "clicked", (GCallback) _tuba_views_admin_timeline_pagination_timeline_on_next_gtk_button_clicked, self, 0);
	_tmp20_ = pagination_buttons;
	_tmp21_ = self->priv->next_button;
	gtk_box_append (_tmp20_, (GtkWidget*) _tmp21_);
	_tmp22_ = g_strdup ("ttl-view");
	_tmp23_ = g_new0 (gchar*, 1 + 1);
	_tmp23_[0] = _tmp22_;
	_tmp24_ = self->content;
	_tmp25_ = _g_object_ref0 ((GtkWidget*) _tmp24_);
	_tmp26_ = (AdwClamp*) adw_clamp_new ();
	gtk_widget_set_vexpand ((GtkWidget*) _tmp26_, TRUE);
	adw_clamp_set_maximum_size (_tmp26_, 670);
	adw_clamp_set_tightening_threshold (_tmp26_, 670);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp26_, _tmp23_);
	_tmp23_ = (_vala_array_free (_tmp23_, 1, (GDestroyNotify) g_free), NULL);
	adw_clamp_set_child (_tmp26_, _tmp25_);
	_g_object_unref0 (_tmp25_);
	g_object_ref_sink (_tmp26_);
	_tmp27_ = _tmp26_;
	gtk_box_append ((GtkBox*) self, (GtkWidget*) _tmp27_);
	_g_object_unref0 (_tmp27_);
	_tmp28_ = pagination_buttons;
	gtk_box_append ((GtkBox*) self, (GtkWidget*) _tmp28_);
	_g_object_unref0 (pagination_buttons);
	return obj;
}

static void
tuba_views_admin_timeline_pagination_timeline_class_init (TubaViewsAdminTimelinePaginationTimelineClass * klass,
                                                          gpointer klass_data)
{
	tuba_views_admin_timeline_pagination_timeline_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsAdminTimelinePaginationTimeline_private_offset);
	((TubaViewsAdminTimelinePaginationTimelineClass *) klass)->request = (void (*) (TubaViewsAdminTimelinePaginationTimeline*, GAsyncReadyCallback, gpointer)) tuba_views_admin_timeline_pagination_timeline_real_request;
	((TubaViewsAdminTimelinePaginationTimelineClass *) klass)->request_finish = (void (*) (TubaViewsAdminTimelinePaginationTimeline*, GAsyncResult*)) tuba_views_admin_timeline_pagination_timeline_real_request_finish;
	((TubaViewsAdminTimelinePaginationTimelineClass *) klass)->on_create_model_widget = (GtkWidget* (*) (TubaViewsAdminTimelinePaginationTimeline*, GObject*)) tuba_views_admin_timeline_pagination_timeline_real_on_create_model_widget;
	((TubaViewsAdminTimelinePaginationTimelineClass *) klass)->on_content_item_activated = (void (*) (TubaViewsAdminTimelinePaginationTimeline*, GtkListBoxRow*)) tuba_views_admin_timeline_pagination_timeline_real_on_content_item_activated;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_views_admin_timeline_pagination_timeline_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_views_admin_timeline_pagination_timeline_set_property;
	G_OBJECT_CLASS (klass)->constructor = tuba_views_admin_timeline_pagination_timeline_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_admin_timeline_pagination_timeline_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_URL_PROPERTY, tuba_views_admin_timeline_pagination_timeline_properties[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_URL_PROPERTY] = g_param_spec_string ("url", "url", "url", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_ACCEPTS_PROPERTY, tuba_views_admin_timeline_pagination_timeline_properties[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_ACCEPTS_PROPERTY] = g_param_spec_gtype ("accepts", "accepts", "accepts", G_TYPE_NONE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_WORKING_PROPERTY, tuba_views_admin_timeline_pagination_timeline_properties[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_WORKING_PROPERTY] = g_param_spec_boolean ("working", "working", "working", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_PAGE_NEXT_PROPERTY, tuba_views_admin_timeline_pagination_timeline_properties[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_PAGE_NEXT_PROPERTY] = g_param_spec_string ("page-next", "page-next", "page-next", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_PAGE_PREV_PROPERTY, tuba_views_admin_timeline_pagination_timeline_properties[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_PAGE_PREV_PROPERTY] = g_param_spec_string ("page-prev", "page-prev", "page-prev", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	tuba_views_admin_timeline_pagination_timeline_signals[TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_ON_ERROR_SIGNAL] = g_signal_new ("on-error", TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__INT_STRING, G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_STRING);
}

static void
tuba_views_admin_timeline_pagination_timeline_instance_init (TubaViewsAdminTimelinePaginationTimeline * self,
                                                             gpointer klass)
{
	gchar* _tmp0_;
	self->priv = tuba_views_admin_timeline_pagination_timeline_get_instance_private (self);
	_tmp0_ = g_strdup ("");
	self->priv->_url = _tmp0_;
	self->priv->_accepts = G_TYPE_NONE;
	self->priv->_working = FALSE;
	self->priv->_page_next = NULL;
	self->priv->_page_prev = NULL;
	self->priv->first_page = TRUE;
}

static void
tuba_views_admin_timeline_pagination_timeline_finalize (GObject * obj)
{
	TubaViewsAdminTimelinePaginationTimeline * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimeline);
	g_debug ("PaginationTimeline.vala:3: Destroying PaginationTimeline");
	_g_object_unref0 (self->content);
	_g_free0 (self->priv->_url);
	_g_free0 (self->priv->_page_next);
	_g_free0 (self->priv->_page_prev);
	_g_object_unref0 (self->priv->prev_button);
	_g_object_unref0 (self->priv->next_button);
	G_OBJECT_CLASS (tuba_views_admin_timeline_pagination_timeline_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_admin_timeline_pagination_timeline_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsAdminTimelinePaginationTimelineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_admin_timeline_pagination_timeline_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsAdminTimelinePaginationTimeline), 0, (GInstanceInitFunc) tuba_views_admin_timeline_pagination_timeline_instance_init, NULL };
	GType tuba_views_admin_timeline_pagination_timeline_type_id;
	tuba_views_admin_timeline_pagination_timeline_type_id = g_type_register_static (gtk_box_get_type (), "TubaViewsAdminTimelinePaginationTimeline", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaViewsAdminTimelinePaginationTimeline_private_offset = g_type_add_instance_private (tuba_views_admin_timeline_pagination_timeline_type_id, sizeof (TubaViewsAdminTimelinePaginationTimelinePrivate));
	return tuba_views_admin_timeline_pagination_timeline_type_id;
}

GType
tuba_views_admin_timeline_pagination_timeline_get_type (void)
{
	static GType tuba_views_admin_timeline_pagination_timeline_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_admin_timeline_pagination_timeline_type_id__once)) {
		GType tuba_views_admin_timeline_pagination_timeline_type_id;
		tuba_views_admin_timeline_pagination_timeline_type_id = tuba_views_admin_timeline_pagination_timeline_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_admin_timeline_pagination_timeline_type_id__once, tuba_views_admin_timeline_pagination_timeline_type_id);
	}
	return tuba_views_admin_timeline_pagination_timeline_type_id__once;
}

static void
_vala_tuba_views_admin_timeline_pagination_timeline_get_property (GObject * object,
                                                                  guint property_id,
                                                                  GValue * value,
                                                                  GParamSpec * pspec)
{
	TubaViewsAdminTimelinePaginationTimeline * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimeline);
	switch (property_id) {
		case TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_URL_PROPERTY:
		g_value_set_string (value, tuba_views_admin_timeline_pagination_timeline_get_url (self));
		break;
		case TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_ACCEPTS_PROPERTY:
		g_value_set_gtype (value, tuba_views_admin_timeline_pagination_timeline_get_accepts (self));
		break;
		case TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_WORKING_PROPERTY:
		g_value_set_boolean (value, tuba_views_admin_timeline_pagination_timeline_get_working (self));
		break;
		case TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_PAGE_NEXT_PROPERTY:
		g_value_set_string (value, tuba_views_admin_timeline_pagination_timeline_get_page_next (self));
		break;
		case TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_PAGE_PREV_PROPERTY:
		g_value_set_string (value, tuba_views_admin_timeline_pagination_timeline_get_page_prev (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_views_admin_timeline_pagination_timeline_set_property (GObject * object,
                                                                  guint property_id,
                                                                  const GValue * value,
                                                                  GParamSpec * pspec)
{
	TubaViewsAdminTimelinePaginationTimeline * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimeline);
	switch (property_id) {
		case TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_URL_PROPERTY:
		tuba_views_admin_timeline_pagination_timeline_set_url (self, g_value_get_string (value));
		break;
		case TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_ACCEPTS_PROPERTY:
		tuba_views_admin_timeline_pagination_timeline_set_accepts (self, g_value_get_gtype (value));
		break;
		case TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_WORKING_PROPERTY:
		tuba_views_admin_timeline_pagination_timeline_set_working (self, g_value_get_boolean (value));
		break;
		case TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_PAGE_NEXT_PROPERTY:
		tuba_views_admin_timeline_pagination_timeline_set_page_next (self, g_value_get_string (value));
		break;
		case TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_PAGE_PREV_PROPERTY:
		tuba_views_admin_timeline_pagination_timeline_set_page_prev (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static gssize
_vala_array_length (gpointer array)
{
	gssize length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}

